Hi,

This patch supports unknown Intel family 0x6 CPUs.  OK for trunk and
4.6 branch?

Thanks.

H.J.
--
2011-06-08  H.J. Lu  <hongjiu...@intel.com>

        * config/i386/driver-i386.c (host_detect_local_cpu): Support
        unknown Intel family 0x6 CPUs.

diff --git a/gcc/config/i386/driver-i386.c b/gcc/config/i386/driver-i386.c
index 4fc6b45..985a6ff 100644
--- a/gcc/config/i386/driver-i386.c
+++ b/gcc/config/i386/driver-i386.c
@@ -587,9 +587,22 @@ const char *host_detect_local_cpu (int argc, const char 
**argv)
        default:
          if (arch)
            {
-             if (has_ssse3)
-               /* If it is an unknown CPU with SSSE3, assume Core 2.  */
-               cpu = "core2";
+             /* This is unknown family 0x6 CPU.  */
+             if (has_avx)
+               /* Assume Sandy Bridge.  */
+               cpu = "corei7-avx";
+             else if (has_sse4_2)
+               /* Assume Core i7.  */
+               cpu = "corei7";
+             else if (has_ssse3)
+               {
+                 if (has_movbe)
+                   /* Assume Atom.  */
+                   cpu = "atom";
+                 else
+                   /* Assume Core 2.  */
+                   cpu = "core2";
+               }
              else if (has_sse3)
                /* It is Core Duo.  */
                cpu = "pentium-m";

Reply via email to